/***************************** C HEADER FILE *********************************
**
**  Project:    RTCU Communication Hub, Heartbeat plug-in
**  Filename:   LOCAL.H 
**  Version:    1.00
**  Date:       June 23, 2020
**  
******************************************************************************
**
**  VERSION HISTORY:
**  ----------------
**  1.00 - June 23, 2020 - Michael Olsen
**  - Exported functions added.
**
*****************************************************************************/
#if !defined(_LOCAL_H_)
#define _LOCAL_H_


/*****************************************************************************
**
**    MODULES USED 
**
*****************************************************************************/


/*****************************************************************************
**
**    DEFINITIONS AND MACROS
**
*****************************************************************************/


/****************************************************************************
**
**    TYPEDEFS AND STRUCTURES
**
****************************************************************************/


/****************************************************************************
** 
**    EXPORTED VARIABLES
**
****************************************************************************/


/****************************************************************************
**
**    EXPORTED FUNCTIONS
**
****************************************************************************/

/////////////////////////////////////////////////////////////////////////////
// This function will write an entry into the RCH log.
//
// Input:
//    type          - The type of log entry.
//                    1 = Error, 2 = Event, 3 = detailed event
//    text          - Pointer to the zero terminated UTF-8 string to enter.
//
// Output:
//    None.
//
// Returns:
//    None.
//
/////////////////////////////////////////////////////////////////////////////
void write_log(const int type, const char *text);

/////////////////////////////////////////////////////////////////////////////
// This function is called from the RCH when a Heartbeat event happens.
//
// Input:
//    NodeID        - The Node ID of the client.
//    State         - The heartbeat event.
//                    1 = The client is online. (first heartbeat received)
//                    2 = The client is offline. (Timeout waiting for heartbeat)
//
// Output:
//    None.
//
// Returns:
//    None.
//
/////////////////////////////////////////////////////////////////////////////
void OnHeartbeat(const long NodeID, const int State);


#endif   /* _LOCAL_H_ */
/****************************************************************************
**
**    EOF 
**
****************************************************************************/
